#include <wx/wx.h>
#include <wx/regex.h>
#include <wx/aboutdlg.h>
#include "MyFrame.h"


int idMenuQuit = ::wxNewId();
int idMenuAbout = ::wxNewId();
int idBtnActivateDesactivate = ::wxNewId();

BEGIN_EVENT_TABLE(MyFrame, wxFrame)
    EVT_MENU(idMenuQuit, MyFrame::OnMenuQuit)
    EVT_MENU(idMenuAbout, MyFrame::OnMenuAbout)

    EVT_BUTTON(idBtnActivateDesactivate, MyFrame::OnClickActivateDesactivate)

    EVT_CLOSE(MyFrame::OnCloseWindow)
END_EVENT_TABLE()


//*** constructors & destructor

MyFrame::MyFrame(const wxString& title, const wxPoint& pos, const wxSize& size)
: wxFrame((wxFrame*)NULL, -1, title, pos, size)
{
    //* drawing of menu bar
    wxMenuBar* menuBar = new wxMenuBar();
    wxMenu* menuFile = new wxMenu();
    wxMenu* menuHelp = new wxMenu();

    menuFile->Append(idMenuQuit, "Quit", "Quit application");
    menuBar->Append(menuFile, "File");

    menuHelp->Append(idMenuAbout, "About", "Information about application");
    menuBar->Append(menuHelp, "Help");

    this->SetMenuBar(menuBar);

    this->CreateStatusBar();


    //* initializations
    this->rkeyApp = new wxRegKey("HKEY_LOCAL_MACHINE\\SOFTWARE\\Classes\\CLSID\\{87D62D94-71B3-4b9a-9489-5FE6850DC73E}\\InProcServer32");

    //* drawing of GUI
    wxPanel* panelMain = new wxPanel(this, -1, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL);
    wxBoxSizer* sizerMain = new wxBoxSizer(wxVERTICAL);

    panelMain->SetSizer(sizerMain);
        sizerMain->AddSpacer(10);
        this->btnActivateDesactivate = new wxButton(panelMain, idBtnActivateDesactivate, wxEmptyString, wxDefaultPosition, wxSize(80,30));
        sizerMain->Add(this->btnActivateDesactivate, 0, wxALIGN_CENTER_HORIZONTAL, 0);

    this->SetStatusText(wxEmptyString);

    this->InitGUI();
}

MyFrame::~MyFrame()
{
    delete this->rkeyApp;
}


//*** specific methods


//* void MyFrame::ActivateDesactivate()
//
// parameters:
// - <none>
// returns:
// - <none>

void MyFrame::ActivateDesactivate()
{
    if ( this->shMediaState ) {
        ::wxExecute("regsvr32 /u /s shmedia.dll", wxEXEC_SYNC);
    }
    else {
        ::wxExecute("regsvr32 /s shmedia.dll", wxEXEC_SYNC);
    }

    this->InitGUI();
}

void MyFrame::InitGUI()
{
    if ( this->rkeyApp->HasValue(wxEmptyString) ) {
        this->shMediaState = true;
        this->txtStatusBar = "ShMedia IS active";
        this->txtButton = "Desactivate";
    }
    else {
        this->shMediaState = false;
        this->txtStatusBar = "ShMedia is NOT active";
        this->txtButton = "Activate";
    }

    this->SetStatusText(this->txtStatusBar);
    this->btnActivateDesactivate->SetLabel(this->txtButton);
}


//*** menu events

void MyFrame::OnMenuQuit(wxCommandEvent& WXUNUSED(event))
{
    this->Close(TRUE); // closes the frame (implicitely generating CLOSE_EVENT)
}


void MyFrame::OnMenuAbout(wxCommandEvent& WXUNUSED(event))
{
    wxAboutDialogInfo aboutDlgInfo;
    aboutDlgInfo.SetName("ShMedia Manager");
    aboutDlgInfo.SetVersion("v1.0");
    aboutDlgInfo.SetCopyright("(2008/04)");
    aboutDlgInfo.SetDescription("ShMedia.dll is a Windows Explorer plugin which\ngives tip information about multimedia files.\n\nby TrV\ncontact: dev(at)arqendra(dot)net\n\nDeveloped with:\n- Code::Blocks 8.02 (nightly build #5322)\n- MinGW 3.4.5\n- wxWidgets 2.8.7\n- UPX 3.04w\n");
    aboutDlgInfo.SetWebSite("http://dev.arqendra.net");

    ::wxAboutBox(aboutDlgInfo);
}


//*** button events

void MyFrame::OnClickActivateDesactivate(wxCommandEvent& WXUNUSED(event))
{
    this->ActivateDesactivate(); // launches DHCP reservations reading from registry
}


//*** frame events

void MyFrame::OnCloseWindow(wxCloseEvent& WXUNUSED(event))
{
    this->Destroy(); // destroys the frame, thus the application
}
